diff --git a/core/modules/comment/lib/Drupal/comment/Tests/CommentInterfaceTest.php b/core/modules/comment/lib/Drupal/comment/Tests/CommentInterfaceTest.php
index 36f9f43..a7e88dd 100644
--- a/core/modules/comment/lib/Drupal/comment/Tests/CommentInterfaceTest.php
+++ b/core/modules/comment/lib/Drupal/comment/Tests/CommentInterfaceTest.php
@@ -109,10 +109,6 @@ function testCommentInterface() {
     $reply = $this->postComment(NULL, $this->randomName(), $this->randomName(), TRUE);
     $this->assertTrue($this->commentExists($reply, TRUE), 'Modified reply found.');
 
-    // Correct link count
-    $this->drupalGet('node');
-    $this->assertRaw('4 comments', 'Link to the 4 comments exist.');
-
     // Confirm a new comment is posted to the correct page.
     $this->setCommentsPerPage(2);
     $comment_new_page = $this->postComment($this->node, $this->randomName(), $this->randomName(), TRUE);
diff --git a/core/modules/comment/lib/Drupal/comment/Tests/CommentLinksTest.php b/core/modules/comment/lib/Drupal/comment/Tests/CommentLinksTest.php
index d049aa3..0df1b71 100644
--- a/core/modules/comment/lib/Drupal/comment/Tests/CommentLinksTest.php
+++ b/core/modules/comment/lib/Drupal/comment/Tests/CommentLinksTest.php
@@ -12,6 +12,15 @@
  */
 class CommentLinksTest extends CommentTestBase {
 
+  /**
+   * Use the main node listing to test rendering on teasers.
+   *
+   * @var array
+   *
+   * @todo Remove this dependency.
+   */
+  public static $modules = array('views');
+
   public static function getInfo() {
     return array(
       'name' => 'Comment links',
diff --git a/core/modules/comment/lib/Drupal/comment/Tests/CommentNewIndicatorTest.php b/core/modules/comment/lib/Drupal/comment/Tests/CommentNewIndicatorTest.php
index 324012e..8009f88 100644
--- a/core/modules/comment/lib/Drupal/comment/Tests/CommentNewIndicatorTest.php
+++ b/core/modules/comment/lib/Drupal/comment/Tests/CommentNewIndicatorTest.php
@@ -12,6 +12,15 @@
  */
 class CommentNewIndicatorTest extends CommentTestBase {
 
+  /**
+   * Use the main node listing to test rendering on teasers.
+   *
+   * @var array
+   *
+   * @todo Remove this dependency.
+   */
+  public static $modules = array('views');
+
   public static function getInfo() {
     return array(
       'name' => "Comment 'new' indicator",
diff --git a/core/modules/contextual/lib/Drupal/contextual/Tests/ContextualDynamicContextTest.php b/core/modules/contextual/lib/Drupal/contextual/Tests/ContextualDynamicContextTest.php
index da786a2..f84e9f4 100644
--- a/core/modules/contextual/lib/Drupal/contextual/Tests/ContextualDynamicContextTest.php
+++ b/core/modules/contextual/lib/Drupal/contextual/Tests/ContextualDynamicContextTest.php
@@ -19,7 +19,7 @@ class ContextualDynamicContextTest extends WebTestBase {
    *
    * @var array
    */
-  public static $modules = array('contextual', 'node');
+  public static $modules = array('contextual', 'node', 'views');
 
   public static function getInfo() {
     return array(
diff --git a/core/modules/locale/lib/Drupal/locale/Tests/LocaleContentTest.php b/core/modules/locale/lib/Drupal/locale/Tests/LocaleContentTest.php
index a424457..3baa919 100644
--- a/core/modules/locale/lib/Drupal/locale/Tests/LocaleContentTest.php
+++ b/core/modules/locale/lib/Drupal/locale/Tests/LocaleContentTest.php
@@ -178,9 +178,9 @@ function testContentTypeDirLang() {
       ));
     }
 
-    $this->drupalGet('node');
 
     // Check if English node does not have lang tag.
+    $this->drupalGet('node/' . $nodes['en']->nid);
     $pattern = '|id="node-' . $nodes['en']->nid . '"[^<>]*lang="en"|';
     $this->assertNoPattern($pattern, 'The lang tag has not been assigned to the English node.');
 
@@ -189,18 +189,18 @@ function testContentTypeDirLang() {
     $this->assertNoPattern($pattern, 'The dir tag has not been assigned to the English node.');
 
     // Check if Arabic node has lang="ar" & dir="rtl" tags.
+    $this->drupalGet('node/' . $nodes['ar']->nid);
     $pattern = '|id="node-' . $nodes['ar']->nid . '"[^<>]*lang="ar" dir="rtl"|';
     $this->assertPattern($pattern, 'The lang and dir tags have been assigned correctly to the Arabic node.');
 
     // Check if Spanish node has lang="es" tag.
+    $this->drupalGet('node/' . $nodes['es']->nid);
     $pattern = '|id="node-' . $nodes['es']->nid . '"[^<>]*lang="es"|';
     $this->assertPattern($pattern, 'The lang tag has been assigned correctly to the Spanish node.');
 
     // Check if Spanish node does not have dir="ltr" tag.
     $pattern = '|id="node-' . $nodes['es']->nid . '"[^<>]*lang="es" dir="ltr"|';
     $this->assertNoPattern($pattern, 'The dir tag has not been assigned to the Spanish node.');
-
-    $this->drupalLogout();
   }
 
 
diff --git a/core/modules/locale/lib/Drupal/locale/Tests/LocalePathTest.php b/core/modules/locale/lib/Drupal/locale/Tests/LocalePathTest.php
index d1ad5f0..4f49d02 100644
--- a/core/modules/locale/lib/Drupal/locale/Tests/LocalePathTest.php
+++ b/core/modules/locale/lib/Drupal/locale/Tests/LocalePathTest.php
@@ -19,7 +19,7 @@ class LocalePathTest extends WebTestBase {
    *
    * @var array
    */
-  public static $modules = array('node', 'locale', 'path');
+  public static $modules = array('node', 'locale', 'path', 'views');
 
   public static function getInfo() {
     return array(
diff --git a/core/modules/node/config/views.view.frontpage.yml b/core/modules/node/config/views.view.frontpage.yml
new file mode 100644
index 0000000..0fbe04d
--- /dev/null
+++ b/core/modules/node/config/views.view.frontpage.yml
@@ -0,0 +1,139 @@
+api_version: '3.0'
+base_field: nid
+base_table: node
+core: 8.x
+description: 'A list of nodes marked for display on the front page.'
+disabled: '0'
+display:
+  default:
+    display_options:
+      access:
+        type: perm
+      cache:
+        type: none
+      empty:
+        area:
+          admin_label: ''
+          content: 'No front page content has been created yet.'
+          empty: '1'
+          field: area
+          format: plain_text
+          group_type: group
+          id: area
+          label: ''
+          relationship: none
+          table: views
+          tokenize: '0'
+        node_listing_empty:
+          admin_label: ''
+          empty: '1'
+          field: node_listing_empty
+          group_type: group
+          id: node_listing_empty
+          label: ''
+          relationship: none
+          table: node
+        title:
+          id: title
+          table: views
+          field: title
+          relationship: none
+          group_type: group
+          admin_label: ''
+          label: ''
+          empty: '1'
+          title: 'Welcome to Drupal'
+      exposed_form:
+        type: basic
+      filters:
+        promote:
+          admin_label: ''
+          expose:
+            description: ''
+            identifier: ''
+            label: ''
+            multiple: '0'
+            operator: ''
+            operator_id: '0'
+            remember: '0'
+            remember_roles:
+              authenticated: authenticated
+            required: '0'
+            use_operator: '0'
+          exposed: '0'
+          field: promote
+          group: '1'
+          group_info:
+            default_group: All
+            default_group_multiple: {  }
+            description: ''
+            group_items: {  }
+            identifier: ''
+            label: ''
+            multiple: '0'
+            optional: '1'
+            remember: '0'
+            widget: select
+          group_type: group
+          id: promote
+          is_grouped: '0'
+          operator: '='
+          relationship: none
+          table: node
+          value: '1'
+        status:
+          expose:
+            operator: '0'
+          field: status
+          group: '1'
+          id: status
+          table: node
+          value: '1'
+      pager:
+        options:
+          items_per_page: '10'
+        type: full
+      query:
+        type: views_query
+      row:
+        options:
+          build_mode: teaser
+          comments: '0'
+          links: '1'
+        type: node
+      sorts:
+        created:
+          field: created
+          id: created
+          order: DESC
+          table: node
+        sticky:
+          admin_label: ''
+          expose:
+            label: ''
+          exposed: '0'
+          field: sticky
+          group_type: group
+          id: sticky
+          order: ASC
+          relationship: none
+          table: node
+      style:
+        type: default
+      title: ''
+    display_plugin: default
+    display_title: Master
+    id: default
+    position: {  }
+  page_1:
+    display_options:
+      path: node
+    display_plugin: page
+    display_title: Page
+    id: page_1
+    position: {  }
+human_name: Frontpage
+langcode: und
+module: node
+name: frontpage
+tag: ''
diff --git a/core/modules/node/lib/Drupal/node/Plugin/views/area/ListingEmpty.php b/core/modules/node/lib/Drupal/node/Plugin/views/area/ListingEmpty.php
new file mode 100644
index 0000000..4e94920
--- /dev/null
+++ b/core/modules/node/lib/Drupal/node/Plugin/views/area/ListingEmpty.php
@@ -0,0 +1,44 @@
+<?php
+
+/**
+ * @file
+ * Contains \Drupal\node\Plugin\views\area\LinkAdd.
+ */
+
+namespace Drupal\node\Plugin\views\area;
+
+use Drupal\Core\Annotation\Plugin;
+use Drupal\views\Plugin\views\area\AreaPluginBase;
+
+/**
+ * Defines an area plugin to display a node/add link.
+ *
+ * @ingroup views_area_handlers
+ *
+ * @Plugin(
+ *   id = "node_listing_empty",
+ *   module = "node"
+ * )
+ */
+class ListingEmpty extends AreaPluginBase {
+
+  /**
+   * Implements \Drupal\views\Plugin\views\area\AreaPluginBase::render().
+   */
+  public function render($empty = FALSE) {
+    if (!$empty || !empty($this->options['empty'])) {
+      $element = array(
+        '#theme' => 'links',
+        '#links' => array(
+          array(
+            'href' => 'node/add',
+            'title' => t('Add new content')
+          )
+        ) ,
+        '#access' => _node_add_access()
+      );
+      return drupal_render($element);
+    }
+  }
+
+}
diff --git a/core/modules/node/lib/Drupal/node/Tests/NodeLoadMultipleTest.php b/core/modules/node/lib/Drupal/node/Tests/NodeLoadMultipleTest.php
index 25cb01d..ad37c69 100644
--- a/core/modules/node/lib/Drupal/node/Tests/NodeLoadMultipleTest.php
+++ b/core/modules/node/lib/Drupal/node/Tests/NodeLoadMultipleTest.php
@@ -12,6 +12,13 @@
  */
 class NodeLoadMultipleTest extends NodeTestBase {
 
+  /**
+   * Enable Views to test the frontpage against node_load_multiple() results.
+   *
+   * @var array
+   */
+  public static $modules = array('views');
+
   public static function getInfo() {
     return array(
       'name' => 'Load multiple nodes',
diff --git a/core/modules/node/lib/Drupal/node/Tests/NodeTitleTest.php b/core/modules/node/lib/Drupal/node/Tests/NodeTitleTest.php
index e657d76..e03e4b0 100644
--- a/core/modules/node/lib/Drupal/node/Tests/NodeTitleTest.php
+++ b/core/modules/node/lib/Drupal/node/Tests/NodeTitleTest.php
@@ -17,7 +17,7 @@ class NodeTitleTest extends NodeTestBase {
    *
    * @var array
    */
-  public static $modules = array('comment');
+  public static $modules = array('comment', 'views');
 
   protected $admin_user;
 
diff --git a/core/modules/node/node.module b/core/modules/node/node.module
index eb56876..8681855 100644
--- a/core/modules/node/node.module
+++ b/core/modules/node/node.module
@@ -1692,13 +1692,6 @@ function node_menu() {
     'access arguments' => array('administer content types'),
     'file' => 'content_types.inc',
   );
-
-  $items['node'] = array(
-    'page callback' => 'node_page_default',
-    'access arguments' => array('access content'),
-    'menu_name' => 'tools',
-    'type' => MENU_CALLBACK,
-  );
   $items['node/add'] = array(
     'title' => 'Add content',
     'page callback' => 'node_add_page',
@@ -2176,62 +2169,6 @@ function node_view_multiple($nodes, $view_mode = 'teaser', $langcode = NULL) {
 }
 
 /**
- * Page callback: Generates a listing of promoted nodes.
- *
- * @return array
- *   An array in the format expected by drupal_render().
- *
- * @see node_menu()
- */
-function node_page_default() {
-  $site_config = config('system.site');
-  $select = db_select('node', 'n')
-    ->fields('n', array('nid', 'sticky', 'created'))
-    ->condition('n.promote', 1)
-    ->condition('n.status', 1)
-    ->orderBy('n.sticky', 'DESC')
-    ->orderBy('n.created', 'DESC')
-    ->extend('Drupal\Core\Database\Query\PagerSelectExtender')
-    ->limit(config('node.settings')->get('items_per_page'))
-    ->addTag('node_access');
-
-  $nids = $select->execute()->fetchCol();
-
-  if (!empty($nids)) {
-    $nodes = node_load_multiple($nids);
-    $build['nodes'] = node_view_multiple($nodes);
-
-    // 'rss.xml' is a path, not a file, registered in node_menu().
-    drupal_add_feed('rss.xml', $site_config->get('name') . ' ' . t('RSS'));
-    $build['pager'] = array(
-      '#theme' => 'pager',
-      '#weight' => 5,
-    );
-    drupal_set_title('');
-  }
-  else {
-    drupal_set_title(t('Welcome to @site-name', array('@site-name' => $site_config->get('name'))), PASS_THROUGH);
-
-    $default_message = '<p>' . t('No front page content has been created yet.') . '</p>';
-
-    $default_links = array();
-    if (_node_add_access()) {
-      $default_links[] = l(t('Add new content'), 'node/add');
-    }
-    if (!empty($default_links)) {
-      $default_message .= theme('item_list', array('items' => $default_links));
-    }
-
-    $build['default_message'] = array(
-      '#markup' => $default_message,
-      '#prefix' => '<div id="first-time">',
-      '#suffix' => '</div>',
-    );
-  }
-  return $build;
-}
-
-/**
  * Page callback: Displays a single node.
  *
  * @param Drupal\node\Node $node
diff --git a/core/modules/node/node.views.inc b/core/modules/node/node.views.inc
index 8f8d75f..36122d0 100644
--- a/core/modules/node/node.views.inc
+++ b/core/modules/node/node.views.inc
@@ -418,6 +418,14 @@ function node_views_data() {
     ),
   );
 
+  $data['node']['node_listing_empty'] = array(
+    'title' => t('Empty Node Frontpage behavior'),
+    'help' => t('Provides a link to the node add overview page.'),
+    'area' => array(
+      'id' => 'node_listing_empty',
+    ),
+  );
+
   // Content revision table
 
   // Define the base group of this table. Fields that don't
diff --git a/core/modules/system/system.install b/core/modules/system/system.install
index b63ca46..076484b 100644
--- a/core/modules/system/system.install
+++ b/core/modules/system/system.install
@@ -2195,6 +2195,16 @@ function system_update_8045() {
 }
 
 /**
+ * Enable Views if the node listing is set as the front page.
+ */
+function system_update_8046() {
+  $front_page = config('system.site')->get('page.front');
+  if (!isset($front_page) || $front_page == 'node') {
+    update_module_enable(array('views'));
+  }
+}
+
+/**
  * @} End of "defgroup updates-7.x-to-8.x".
  * The next series of updates should start at 9000.
  */
diff --git a/core/modules/views/config/views.view.frontpage.yml b/core/modules/views/config/views.view.frontpage.yml
deleted file mode 100644
index a635a0e..0000000
--- a/core/modules/views/config/views.view.frontpage.yml
+++ /dev/null
@@ -1,95 +0,0 @@
-disabled: true
-api_version: '3.0'
-module: node
-name: frontpage
-description: 'Emulates the default Drupal front page; you may set the default home page path to this view to make it your front page.'
-tag: default
-base_table: node
-human_name: 'Front page'
-core: '8'
-display:
-  default:
-    id: default
-    display_title: Master
-    display_plugin: default
-    position: '1'
-    display_options:
-      query:
-        type: views_query
-        options:
-          query_comment: false
-      access:
-        type: none
-      cache:
-        type: none
-      exposed_form:
-        type: basic
-      pager:
-        type: full
-      style:
-        type: default
-      row:
-        type: node
-        options:
-          links: 1
-      sorts:
-        sticky:
-          id: sticky
-          table: node
-          field: sticky
-          order: DESC
-        created:
-          id: created
-          table: node
-          field: created
-          order: DESC
-      filters:
-        promote:
-          id: promote
-          table: node
-          field: promote
-          value: '1'
-          group: 0
-          expose:
-            operator: false
-        status:
-          id: status
-          table: node
-          field: status
-          value: '1'
-          group: 0
-          expose:
-            operator: false
-  page_1:
-    id: page_1
-    display_title: Page
-    display_plugin: page
-    position: '2'
-    display_options:
-      query:
-        type: views_query
-        options: {  }
-      path: frontpage
-  feed_1:
-    id: feed_1
-    display_title: Feed
-    display_plugin: feed
-    position: '3'
-    display_options:
-      query:
-        type: views_query
-        options: {  }
-      defaults:
-        title: false
-      title: 'Front page feed'
-      pager:
-        type: some
-      style:
-        type: rss
-      row:
-        type: node_rss
-      path: rss.xml
-      displays:
-        default: default
-        page: page
-      sitename_title: '1'
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/area/AreaPluginBase.php b/core/modules/views/lib/Drupal/views/Plugin/views/area/AreaPluginBase.php
index 8ce189a..8e32514 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/area/AreaPluginBase.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/area/AreaPluginBase.php
@@ -162,9 +162,7 @@ public function preRender(array $results) {
   /**
    * Render the area
    */
-  function render($empty = FALSE) {
-    return '';
-  }
+  abstract function render($empty = FALSE);
 
   /**
    * Area handlers shouldn't have groupby.
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/area/Title.php b/core/modules/views/lib/Drupal/views/Plugin/views/area/Title.php
index 52f6a7a..66dcb2f 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/area/Title.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/area/Title.php
@@ -58,4 +58,12 @@ public function preRender(array $results) {
     return '';
   }
 
+  /**
+   * Implements \Drupal\views\Plugin\views\area\AreaPluginBase().
+   */
+  public function render($empty = FALSE) {
+    // Do nothing for this area handler.
+  }
+
+
 }
diff --git a/core/modules/views/lib/Drupal/views/Tests/AnalyzeTest.php b/core/modules/views/lib/Drupal/views/Tests/AnalyzeTest.php
index cd0e317..3c05374 100644
--- a/core/modules/views/lib/Drupal/views/Tests/AnalyzeTest.php
+++ b/core/modules/views/lib/Drupal/views/Tests/AnalyzeTest.php
@@ -41,10 +41,8 @@ public function setUp() {
    */
   function testAnalyzeBasic() {
     $this->drupalLogin($this->admin);
-    // Enable the frontpage view and click the analyse button.
-    $view = views_get_view('frontpage');
 
-    $this->drupalGet('admin/structure/views/view/frontpage/edit');
+    $this->drupalGet('admin/structure/views/view/test_view/edit');
     $this->assertLink(t('analyze view'));
 
     // This redirects the user to the analyze form.
diff --git a/core/modules/views/lib/Drupal/views/Tests/Handler/AreaTest.php b/core/modules/views/lib/Drupal/views/Tests/Handler/AreaTest.php
index 44dac15..fe68d3a 100644
--- a/core/modules/views/lib/Drupal/views/Tests/Handler/AreaTest.php
+++ b/core/modules/views/lib/Drupal/views/Tests/Handler/AreaTest.php
@@ -175,7 +175,7 @@ public function testTitleArea() {
 
     $view->storage->enable();
 
-    $this->drupalGet('frontpage');
+    $this->drupalGet('node');
     $this->assertText('Overridden title', 'Overridden title found.');
   }
 
diff --git a/core/modules/views/lib/Drupal/views/Tests/Handler/RelationshipTest.php b/core/modules/views/lib/Drupal/views/Tests/Handler/RelationshipTest.php
index cbab5ea..55ba626 100644
--- a/core/modules/views/lib/Drupal/views/Tests/Handler/RelationshipTest.php
+++ b/core/modules/views/lib/Drupal/views/Tests/Handler/RelationshipTest.php
@@ -8,13 +8,14 @@
 namespace Drupal\views\Tests\Handler;
 
 use Drupal\views\Tests\ViewUnitTestBase;
+use Drupal\views\Tests\Plugin\RelationshipJoinTestBase;
 
 /**
  * Tests the base relationship handler.
  *
  * @see Drupal\views\Plugin\views\relationship\RelationshipPluginBase
  */
-class RelationshipTest extends ViewUnitTestBase {
+class RelationshipTest extends RelationshipJoinTestBase {
 
   /**
    * Views used by this test.
@@ -23,6 +24,7 @@ class RelationshipTest extends ViewUnitTestBase {
    */
   public static $testViews = array('test_view');
 
+
   /**
    * Maps between the key in the expected result and the query result.
    *
@@ -41,56 +43,6 @@ public static function getInfo() {
     );
   }
 
-  protected function setUp() {
-    parent::setUp();
-
-    $this->enableModules(array('field', 'user'));
-  }
-
-  /**
-   * Overrides Drupal\views\Tests\ViewTestBase::schemaDefinition().
-   *
-   * Adds a uid column to test the relationships.
-   *
-   * @return array
-   */
-  protected function schemaDefinition() {
-    $schema = parent::schemaDefinition();
-
-    $schema['views_test_data']['fields']['uid'] = array(
-      'description' => "The {users}.uid of the author of the beatle entry.",
-      'type' => 'int',
-      'unsigned' => TRUE,
-      'not null' => TRUE,
-      'default' => 0
-    );
-
-    return $schema;
-  }
-
-
-  /**
-   * Overrides Drupal\views\Tests\ViewTestBase::viewsData().
-   *
-   * Adds a relationship for the uid column.
-   *
-   * @return array
-   */
-  protected function viewsData() {
-    $data = parent::viewsData();
-    $data['views_test_data']['uid'] = array(
-      'title' => t('UID'),
-      'help' => t('The test data UID'),
-      'relationship' => array(
-        'id' => 'standard',
-        'base' => 'users',
-        'base field' => 'uid'
-      )
-    );
-
-    return $data;
-  }
-
   /**
    * Tests the query result of a view with a relationship.
    */
diff --git a/core/modules/views/lib/Drupal/views/Tests/Plugin/DisplayTest.php b/core/modules/views/lib/Drupal/views/Tests/Plugin/DisplayTest.php
index 4883ad5..4ed379d 100644
--- a/core/modules/views/lib/Drupal/views/Tests/Plugin/DisplayTest.php
+++ b/core/modules/views/lib/Drupal/views/Tests/Plugin/DisplayTest.php
@@ -56,7 +56,7 @@ public function setUp() {
    * @see Drupal\views_test_data\Plugin\views\display\DisplayTest
    */
   function testDisplayPlugin() {
-    $view = views_get_view('frontpage');
+    $view = views_get_view('test_view');
 
     // Add a new 'display_test' display and test it's there.
     $view->storage->addDisplay('display_test');
@@ -95,7 +95,7 @@ function testDisplayPlugin() {
     $this->assertTrue(strpos($output, '<h1>Test option title</h1>') !== FALSE, 'The test_option value found in display output title.');
 
     // Test that the display category/summary is in the UI.
-    $this->drupalGet('admin/structure/views/view/frontpage/edit/display_test_1');
+    $this->drupalGet('admin/structure/views/view/test_view/edit/display_test_1');
     $this->assertText('Display test settings');
 
     $this->clickLink('Test option title');
@@ -104,7 +104,7 @@ function testDisplayPlugin() {
     $this->drupalPost(NULL, array('test_option' => $this->randomString), t('Apply'));
 
     // Check the new value has been saved by checking the UI summary text.
-    $this->drupalGet('admin/structure/views/view/frontpage/edit/display_test_1');
+    $this->drupalGet('admin/structure/views/view/test_view/edit/display_test_1');
     $this->assertRaw($this->randomString);
 
     // Test the enable/disable status of a display.
diff --git a/core/modules/views/lib/Drupal/views/Tests/Plugin/JoinTest.php b/core/modules/views/lib/Drupal/views/Tests/Plugin/JoinTest.php
index 8430a45..a8948e0 100644
--- a/core/modules/views/lib/Drupal/views/Tests/Plugin/JoinTest.php
+++ b/core/modules/views/lib/Drupal/views/Tests/Plugin/JoinTest.php
@@ -13,8 +13,11 @@
 
 /**
  * Tests a generic join plugin and the join plugin base.
+ *
+ * @see \Drupal\views_test_data\Plugin\views\join\JoinTest
+ * @see \Drupal\views\Plugin\views\join\JoinPluginBase
  */
-class JoinTest extends PluginTestBase {
+class JoinTest extends RelationshipJoinTestBase {
 
   /**
    * A plugin manager which handlers the instances of joins.
@@ -45,12 +48,12 @@ protected function setUp() {
   public function testExamplePlugin() {
 
     // Setup a simple join and test the result sql.
-    $view = views_get_view('frontpage');
+    $view = views_get_view('test_view');
     $view->initDisplay();
     $view->initQuery();
 
     $configuration = array(
-      'left_table' => 'node',
+      'left_table' => 'views_test_data',
       'left_field' => 'uid',
       'table' => 'users',
       'field' => 'uid',
@@ -61,14 +64,14 @@ public function testExamplePlugin() {
     $rand_int = rand(0, 1000);
     $join->setJoinValue($rand_int);
 
-    $query = db_select('node');
+    $query = db_select('views_test_data');
     $table = array('alias' => 'users');
     $join->buildJoin($query, $table, $view->query);
 
     $tables = $query->getTables();
     $join_info = $tables['users'];
-    debug($join_info);
-    $this->assertTrue(strpos($join_info['condition'], "node.uid = $rand_int") !== FALSE, 'Make sure that the custom join plugin can extend the join base and alter the result.');
+    debug($join_info['condition']);
+    $this->assertTrue(strpos($join_info['condition'], "views_test_data.uid = $rand_int") !== FALSE, 'Make sure that the custom join plugin can extend the join base and alter the result.');
   }
 
   /**
@@ -77,14 +80,14 @@ public function testExamplePlugin() {
   public function testBasePlugin() {
 
     // Setup a simple join and test the result sql.
-    $view = views_get_view('frontpage');
+    $view = views_get_view('test_view');
     $view->initDisplay();
     $view->initQuery();
 
     // First define a simple join without an extra condition.
     // Set the various options on the join object.
     $configuration = array(
-      'left_table' => 'node',
+      'left_table' => 'views_test_data',
       'left_field' => 'uid',
       'table' => 'users',
       'field' => 'uid',
@@ -97,7 +100,7 @@ public function testBasePlugin() {
 
     // Build the actual join values and read them back from the dbtng query
     // object.
-    $query = db_select('node');
+    $query = db_select('views_test_data');
     $table = array('alias' => 'users');
     $join->buildJoin($query, $table, $view->query);
 
@@ -106,7 +109,7 @@ public function testBasePlugin() {
     $this->assertEqual($join_info['join type'], 'LEFT', 'Make sure the default join type is LEFT');
     $this->assertEqual($join_info['table'], $configuration['table']);
     $this->assertEqual($join_info['alias'], 'users');
-    $this->assertEqual($join_info['condition'], 'node.uid = users.uid');
+    $this->assertEqual($join_info['condition'], 'views_test_data.uid = users.uid');
 
     // Set a different alias and make sure table info is as expected.
     $join = $this->manager->createInstance('standard', $configuration);
diff --git a/core/modules/views/lib/Drupal/views/Tests/Plugin/PagerTest.php b/core/modules/views/lib/Drupal/views/Tests/Plugin/PagerTest.php
index b8d2e74..78e859f 100644
--- a/core/modules/views/lib/Drupal/views/Tests/Plugin/PagerTest.php
+++ b/core/modules/views/lib/Drupal/views/Tests/Plugin/PagerTest.php
@@ -44,13 +44,16 @@ public function testStorePagerSettings() {
     $this->drupalLogin($admin_user);
     // Test behaviour described in http://drupal.org/node/652712#comment-2354918.
 
-    $this->drupalGet('admin/structure/views/view/frontpage/edit');
-
+    $this->drupalGet('admin/structure/views/view/test_view/edit');
 
     $edit = array(
+      'pager[type]' => 'full',
+    );
+    $this->drupalPost('admin/structure/views/nojs/display/test_view/default/pager', $edit, t('Apply'));
+    $edit = array(
       'pager_options[items_per_page]' => 20,
     );
-    $this->drupalPost('admin/structure/views/nojs/display/frontpage/default/pager_options', $edit, t('Apply'));
+    $this->drupalPost('admin/structure/views/nojs/display/test_view/default/pager_options', $edit, t('Apply'));
     $this->assertText('20 items');
 
     // Change type and check whether the type is new type is stored.
@@ -58,8 +61,8 @@ public function testStorePagerSettings() {
     $edit = array(
       'pager[type]' => 'mini',
     );
-    $this->drupalPost('admin/structure/views/nojs/display/frontpage/default/pager', $edit, t('Apply'));
-    $this->drupalGet('admin/structure/views/view/frontpage/edit');
+    $this->drupalPost('admin/structure/views/nojs/display/test_view/default/pager', $edit, t('Apply'));
+    $this->drupalGet('admin/structure/views/view/test_view/edit');
     $this->assertText('Mini', 'Changed pager plugin, should change some text');
 
     // Test behaviour described in http://drupal.org/node/652712#comment-2354400
diff --git a/core/modules/views/lib/Drupal/views/Tests/Plugin/RelationshipJoinTestBase.php b/core/modules/views/lib/Drupal/views/Tests/Plugin/RelationshipJoinTestBase.php
new file mode 100644
index 0000000..63a9f23
--- /dev/null
+++ b/core/modules/views/lib/Drupal/views/Tests/Plugin/RelationshipJoinTestBase.php
@@ -0,0 +1,70 @@
+<?php
+
+/**
+ * @file
+ * Contains \Drupal\views\Tests\Plugin\RelationshipJoinTestBase.
+ */
+
+namespace Drupal\views\Tests\Plugin;
+
+/**
+ * Provies a base class for a testing a relationship.
+ *
+ * @see \Drupal\views\Tests\Handler\JoinTest
+ * @see \Drupal\views\Tests\Plugin\RelationshipTest
+ */
+abstract class RelationshipJoinTestBase extends PluginTestBase {
+
+  /**
+   * Modules to enable.
+   *
+   * @var array
+   */
+  public static $modules = array('user');
+
+  protected function setUp() {
+    parent::setUp();
+
+    $this->enableViewsTestModule();
+  }
+
+  /**
+   * Overrides \Drupal\views\Tests\ViewTestBase::schemaDefinition().
+   *
+   * Adds a uid column to test the relationships.
+   */
+  protected function schemaDefinition() {
+    $schema = parent::schemaDefinition();
+
+    $schema['views_test_data']['fields']['uid'] = array(
+      'description' => "The {users}.uid of the author of the beatle entry.",
+      'type' => 'int',
+      'unsigned' => TRUE,
+      'not null' => TRUE,
+      'default' => 0
+    );
+
+    return $schema;
+  }
+
+  /**
+   * Overrides \Drupal\views\Tests\ViewTestBase::viewsData().
+   *
+   * Adds a relationship for the uid column.
+   */
+  protected function viewsData() {
+    $data = parent::viewsData();
+    $data['views_test_data']['uid'] = array(
+      'title' => t('UID'),
+      'help' => t('The test data UID'),
+      'relationship' => array(
+        'id' => 'standard',
+        'base' => 'users',
+        'base field' => 'uid'
+      )
+    );
+
+    return $data;
+  }
+
+}
diff --git a/core/modules/views/tests/views_test_data/lib/Drupal/views_test_data/Plugin/views/join/JoinTest.php b/core/modules/views/tests/views_test_data/lib/Drupal/views_test_data/Plugin/views/join/JoinTest.php
index 5d0cb73..48060f0 100644
--- a/core/modules/views/tests/views_test_data/lib/Drupal/views_test_data/Plugin/views/join/JoinTest.php
+++ b/core/modules/views/tests/views_test_data/lib/Drupal/views_test_data/Plugin/views/join/JoinTest.php
@@ -51,7 +51,7 @@ public function setJoinValue($join_value) {
    */
   public function buildJoin($select_query, $table, $view_query) {
     // Add an additional hardcoded condition to the query.
-    $this->extra = 'node.uid = ' . $this->getJoinValue();
+    $this->extra = 'views_test_data.uid = ' . $this->getJoinValue();
     parent::buildJoin($select_query, $table, $view_query);
   }
 
diff --git a/core/profiles/minimal/minimal.install b/core/profiles/minimal/minimal.install
index 0c3aafb..cc47f49 100644
--- a/core/profiles/minimal/minimal.install
+++ b/core/profiles/minimal/minimal.install
@@ -14,9 +14,6 @@
 function minimal_install() {
   $default_theme = 'stark';
 
-  // Set front page to "node".
-  config('system.site')->set('page.front', 'node')->save();
-
   // Allow visitor account creation, but with administrative approval.
   config('user.settings')->set('register', USER_REGISTER_VISITORS_ADMINISTRATIVE_APPROVAL)->save();
 

diff --git a/core/modules/views/lib/Drupal/views/Tests/UI/DefaultViewsTest.php b/core/modules/views/lib/Drupal/views/Tests/UI/DefaultViewsTest.php
index a96172b..a6633dd 100644
--- a/core/modules/views/lib/Drupal/views/Tests/UI/DefaultViewsTest.php
+++ b/core/modules/views/lib/Drupal/views/Tests/UI/DefaultViewsTest.php
@@ -33,7 +33,7 @@ public static function getInfo() {
   function testDefaultViews() {
     // Make sure the front page view starts off as disabled (does not appear on
     // the listing page).
-    $edit_href = 'admin/structure/views/view/frontpage/edit';
+    $edit_href = 'admin/structure/views/view/glossary/edit';
     $this->drupalGet('admin/structure/views');
     // @todo Disabled default views do now appear on the front page. Test this
     // behavior with templates instead.
@@ -42,23 +42,23 @@ function testDefaultViews() {
     // Enable the front page view, and make sure it is now visible on the main
     // listing page.
     $this->drupalGet('admin/structure/views/templates');
-    $this->clickViewsOperationLink(t('Enable'), '/frontpage/');
+    $this->clickViewsOperationLink(t('Enable'), '/glossary/');
     $this->assertUrl('admin/structure/views');
     $this->assertLinkByHref($edit_href);
 
     // It should not be possible to revert the view yet.
     // @todo Figure out how to handle this with the new configuration system.
     // $this->assertNoLink(t('Revert'));
-    // $revert_href = 'admin/structure/views/view/frontpage/revert';
+    // $revert_href = 'admin/structure/views/view/glossary/revert';
     // $this->assertNoLinkByHref($revert_href);
 
     // Edit the view and change the title. Make sure that the new title is
     // displayed.
     $new_title = $this->randomName(16);
     $edit = array('title' => $new_title);
-    $this->drupalPost('admin/structure/views/nojs/display/frontpage/page_1/title', $edit, t('Apply'));
-    $this->drupalPost('admin/structure/views/view/frontpage/edit/page_1', array(), t('Save'));
-    $this->drupalGet('frontpage');
+    $this->drupalPost('admin/structure/views/nojs/display/glossary/page_1/title', $edit, t('Apply'));
+    $this->drupalPost('admin/structure/views/view/glossary/edit/page_1', array(), t('Save'));
+    $this->drupalGet('glossary');
     $this->assertResponse(200);
     $this->assertText($new_title);
 
@@ -77,7 +77,7 @@ function testDefaultViews() {
     // $this->assertLink(t('Revert'));
     // $this->assertLinkByHref($revert_href);
     // $this->drupalPost($revert_href, array(), t('Revert'));
-    // $this->drupalGet('frontpage');
+    // $this->drupalGet('glossary');
     // $this->assertNoText($new_title);
 
     // Clone the view and check that the normal schema of cloned views is used.
@@ -86,7 +86,7 @@ function testDefaultViews() {
     $edit = array(
       'name' => 'clone_of_frontpage',
     );
-    $this->assertTitle(t('Clone of @human_name | @site-name', array('@human_name' => 'Front page', '@site-name' => config('system.site')->get('name'))));
+    $this->assertTitle(t('Clone of @human_name | @site-name', array('@human_name' => 'Frontpage', '@site-name' => config('system.site')->get('name'))));
     $this->drupalPost(NULL, $edit, t('Clone'));
     $this->assertUrl('admin/structure/views/view/clone_of_frontpage/edit', array(), 'The normal cloning name schema is applied.');
 
@@ -102,19 +102,19 @@ function testDefaultViews() {
     // listing page.
     // @todo Test this behavior with templates instead.
     $this->drupalGet('admin/structure/views');
-    $this->clickViewsOperationLink(t('Disable'), '/frontpage/');
+    $this->clickViewsOperationLink(t('Disable'), '/glossary/');
     // $this->assertUrl('admin/structure/views');
     // $this->assertNoLinkByHref($edit_href);
     // The easiest way to verify it appears on the disabled views listing page
     // is to try to click the "enable" link from there again.
     $this->drupalGet('admin/structure/views/templates');
-    $this->clickViewsOperationLink(t('Enable'), '/frontpage/');
+    $this->clickViewsOperationLink(t('Enable'), '/glossary/');
     $this->assertUrl('admin/structure/views');
     $this->assertLinkByHref($edit_href);
 
     // Test deleting a view.
     $this->drupalGet('admin/structure/views');
-    $this->clickViewsOperationLink(t('Delete'), '/frontpage/');
+    $this->clickViewsOperationLink(t('Delete'), '/glossary/');
     // Submit the confirmation form.
     $this->drupalPost(NULL, array(), t('Delete'));
     // Ensure the view is no longer listed.
@@ -165,7 +165,7 @@ function testSplitListing() {
    * @param $unique_href_part
    *   A unique string that is expected to occur within the href of the desired
    *   link. For example, if the link URL is expected to look like
    *   "admin/structure/views/view/frontpage/...", then "/frontpage/" could be
    *   passed as the expected unique string.
    *
    * @return
@@ -165,7 +165,7 @@ function testSplitListing() {
    *   A unique string that is expected to occur within the href of the desired
    *   link. For example, if the link URL is expected to look like
-   *   "admin/structure/views/view/frontpage/...", then "/frontpage/" could be
+   *   "admin/structure/views/view/glossary/...", then "/glossary/" could be
    *   passed as the expected unique string.
    *